% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Pre_processing_species_list.R
\name{Pre_processing_species_list}
\alias{Pre_processing_species_list}
\title{Pre-process a list of spiked-in species in a phyloseq object}
\usage{
Pre_processing_species_list(
  physeq,
  spiked_species,
  merge_method = c("sum", "max"),
  output_file = NULL
)
}
\arguments{
\item{physeq}{A \code{phyloseq} object containing the microbiome data.}

\item{spiked_species}{A character vector of spiked-in species names to be processed. Species names should match the \code{Genus Species} format in the phyloseq object (e.g., "Pseudomonas aeruginosa").}

\item{merge_method}{A character string specifying the method to use for merging ASVs. Either \code{"sum"} to sum the counts, or \code{"max"} to keep the maximum abundance ASV. Default is \code{"sum"}.}

\item{output_file}{Optional. A file path to save the merged phyloseq object. If provided, the merged object will be saved as an \code{.rds} file.}
}
\value{
A \code{phyloseq} object with the spiked-in species pre-processed.
}
\description{
This function pre-processes a list of spiked-in species in a phyloseq object
by merging ASVs based on a specified method (sum or max). It retains the Genus
and Species information for the merged taxa as a single entry in the taxonomy table.
}
\examples{
\dontrun{
# Example usage
spiked_species <- c("Pseudomonas aeruginosa", "Escherichia coli", "Clostridium difficile")
merged_physeq_sum <- Pre_processing_species_list(physeq, spiked_species, merge_method = "sum")
merged_physeq_sum@tax_table
merged_physeq_sum@otu_table
}
}
